@@ -599,7 +599,11 @@ class OpenAIProvider(ILLMClient):
                         outs = [it for it in context_items if isinstance(it, dict) and it.get("type") in {
                             "function_call_output", "custom_tool_call_output", "function_result", "tool_result"
                         }]
-                        _log.debug(f"[follow-up] outputs={len(outs)} call_ids={[it.get('call_id') for it in outs]}")
+                        types = [it.get("type") for it in (context_items or []) if isinstance(it, dict)]
+                        cids = [it.get('call_id') for it in outs]
+                        msg = f"[follow-up] prev={previous_response_id} outputs={len(outs)} types={types} call_ids={cids}"
+                        # Log também em INFO para garantir visibilidade em produção
+                        _log.info(msg)
                     except Exception:
                         pass
 
